@@ -492,7 +492,10 @@ class Cursor(object):
 
 
 def _unknownSqlTypeConverter(rs, col):
-    return str(rs.getObject(col))
+    java_val = rs.getObject(col)
+    if java_val is None:
+        return
+    return str(java_val)
 
 
 def _to_datetime(rs, col):
@@ -530,9 +533,13 @@ def _to_binary(rs, col):
     m_TypeName = str(java_val.getClass().getTypeName())
     if m_TypeName == "byte[]":
         return binascii.b2a_hex(java_val)
+    elif m_TypeName in ("java.sql.Blob", "oracle.sql.BLOB"):
+        return binascii.b2a_hex(java_val.getBytes(1, 1024))
+    elif m_TypeName.find("JDBCBlobClient") != -1 :
+        return binascii.b2a_hex(java_val.getBytes(1, 1024))
     else:
-        raise SQLCliException(
-            "SQLCLI-00000: Unknown java class type [" + m_TypeName + "] in _to_binary")
+        # return binascii.b2a_hex(java_val.getBytes(0, 1024))
+        raise SQLCliException("SQLCLI-00000: Unknown java class type [" + m_TypeName + "] in _to_binary")
 
 
 def _java_to_py(java_method):
@@ -555,6 +562,10 @@ def _java_to_py_bigdecimal():
         m_TypeName = str(java_val.getClass().getTypeName())
         if m_TypeName == "java.math.BigDecimal":
             return decimal.Decimal(java_val.stripTrailingZeros().toPlainString())
+        elif m_TypeName == "java.lang.Long":
+            return decimal.Decimal(java_val.toString())
+        elif m_TypeName == "java.math.BigInteger":
+            return decimal.Decimal(java_val.toString())
         else:
             raise SQLCliException(
                 "SQLCLI-00000: Unknown java class type [" + m_TypeName + "] in _java_to_py_bigdecimal")
@@ -613,6 +624,8 @@ _DEFAULT_CONVERTERS = {
     # see
     # http://download.oracle.com/javase/8/docs/api/java/sql/Types.html
     # for possible keys
+    'CHAR': _java_to_py_str(),
+    'LONGVARCHAR': _java_to_py_str(),
     'VARCHAR':  _java_to_py_str(),
     'TIMESTAMP_WITH_TIMEZONE': _java_to_py_timestampwithtimezone(),
     'TIMESTAMP': _to_datetime,
@@ -621,6 +634,7 @@ _DEFAULT_CONVERTERS = {
     'VARBINARY': _to_binary,
     'BINARY': _to_binary,
     'LONGVARBINARY': _to_binary,
+    'BLOB': _to_binary,
     'DECIMAL': _java_to_py_bigdecimal(),
     'NUMERIC': _java_to_py_bigdecimal(),
     'DOUBLE': _java_to_py('doubleValue'),
@@ -629,6 +643,7 @@ _DEFAULT_CONVERTERS = {
     'TINYINT': _java_to_py('intValue'),
     'INTEGER': _java_to_py('intValue'),
     'SMALLINT': _java_to_py('intValue'),
+    'BIGINT':  _java_to_py_bigdecimal(),
     'BOOLEAN': _java_to_py('booleanValue'),
     'BIT': _java_to_py('booleanValue')
 }
